import FileButton from '@/components/FileViewRedirectButton/FileButton'
import { css } from '@emotion/css'
import type { ToolDetails } from '@inject/graphql/fragments/ToolDetails.generated'
import type { FC } from 'react'

const wrapper = css`
  display: flex;
  flex-direction: column;
  align-items: flex-start;
  height: 100%;
  width: 100%;
  gap: 0.5rem;
`

const emphasized = css`
  font-weight: bold;
`

interface ToolContentProps {
  details: ToolDetails
  teamId: string
  exerciseId: string
  inInstructor: boolean
  allowFileRedirect: boolean
}

const ToolContent: FC<ToolContentProps> = ({
  details,
  teamId,
  exerciseId,
  inInstructor,
  allowFileRedirect,
}) => (
  <div className={wrapper}>
    {details.tool.hasParam && (
      <>
        <div className={emphasized}>argument:</div>
        <div>{details.argument}</div>
        <div />
        <div className={emphasized}>response:</div>
      </>
    )}
    <div
      dangerouslySetInnerHTML={{
        __html: details.content.rendered,
      }}
    />
    {details.content.fileInfo && (
      <div
        style={{
          marginTop: details.content.rendered ? '10px' : undefined,
        }}
      >
        <FileButton
          teamId={teamId}
          fileInfo={details.content.fileInfo}
          exerciseId={exerciseId}
          inInstructor={inInstructor}
          allowRedirect={allowFileRedirect}
        />
      </div>
    )}
  </div>
)

export default ToolContent
