import { Button, Callout, InputGroup } from '@blueprintjs/core'
import type { ExtendedTool } from '@inject/graphql/fragments/ExtendedToolType.generated'
import { usePerformTeamToolAction } from '@inject/graphql/mutations/PerformTeamToolAction.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC, KeyboardEventHandler } from 'react'
import { useState } from 'react'

interface GrapheneFormProps {
  grapheneTool: ExtendedTool
  teamId: string
  setOpen(arg0: boolean): void
}

const GrapheneForm: FC<GrapheneFormProps> = ({
  grapheneTool,
  teamId,
  setOpen,
}) => {
  const { tooltipDescription, id } = grapheneTool
  const [mutate] = usePerformTeamToolAction()
  const [value, setValue] = useState<string>('')
  const { notify } = useNotifyContext()

  const mutateData = () => {
    mutate({
      variables: {
        teamId,
        toolId: id || 'none',
        toolArgument: value.trim(),
      },
    })
    notify('Submitted')
    setOpen(false)
    setValue('')
  }
  const handleEnter: KeyboardEventHandler<HTMLInputElement> = e => {
    if (e.key === 'Enter') mutateData()
  }

  return (
    <Callout>
      <p>{tooltipDescription}</p>
      {grapheneTool.hasParam && (
        <InputGroup
          placeholder={grapheneTool.hint || 'Argument'}
          value={value}
          onChange={e => setValue(e.currentTarget.value)}
          onKeyDown={handleEnter}
        />
      )}
      <Button onClick={mutateData}>Submit</Button>
    </Callout>
  )
}

export default GrapheneForm
