import ExerciseListWrapper from '@/components/ExerciseList/ExerciseListWrapper'
import type { ButtonProps } from '@blueprintjs/core'
import {
  Button,
  ButtonGroup,
  Overlay2,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { useHost } from '@inject/graphql/connection/host'
import type { Exercise } from '@inject/graphql/fragments/Exercise.generated'
import useExercisesSubscription from '@inject/graphql/utils/useExercisesSubscription'
import { exportImportUrl } from '@inject/shared/config'
import type { FC } from 'react'
import { useState } from 'react'
import { useLocation, useNavigate } from 'react-router-dom'
import { useParams } from '../../router'
import ImportDialog from './ImportDialog'

interface ExerciseSelectorProps {
  buttonProps?: ButtonProps | undefined
}

const ExerciseSelector: FC<ExerciseSelectorProps> = ({ buttonProps }) => {
  const host = useHost()
  const nav = useNavigate()

  const [isOpen, setIsOpen] = useState(false)
  const [isImportOpen, setIsImportOpen] = useState(false)

  const { exerciseId } = useParams('/analyst/:exerciseId')
  const { pathname } = useLocation()

  // TODO: will have to be reworked if routing changes
  const regex = /\/analyst\/?(\d+)?(\/[^\s]+)?/g
  const match = regex.exec(pathname)
  if (!match)
    throw new Error(
      `ExerciseSelector on page '${pathname}' => doesn't match expected path`
    )
  const suffix = match.at(2) || ''

  const { data, loading, error, refetch } = useExercisesSubscription()

  return (
    <>
      <Button
        style={{ whiteSpace: 'nowrap' }}
        onClick={() => setIsOpen(true)}
        {...buttonProps}
      />
      <Overlay2 isOpen={isOpen} onClose={() => setIsOpen(false)}>
        <Section
          title='Exercise selector'
          rightElement={
            <ButtonGroup minimal>
              <a href={exportImportUrl(host || '')}>
                <Button icon='export'>Export</Button>
              </a>
              <Button onClick={() => setIsImportOpen(true)} icon='import'>
                Import
              </Button>
            </ButtonGroup>
          }
        >
          <SectionCard>
            <ExerciseListWrapper
              data={data}
              loading={loading}
              error={error}
              isSelected={(exercise: Exercise) => exercise.id === exerciseId}
              type='selecting'
              details={{
                onSelect: exercise => {
                  setIsOpen(false)
                  nav(`/analyst/${exercise.id}${suffix}`)
                },
              }}
            />
          </SectionCard>
        </Section>
      </Overlay2>
      <ImportDialog
        isOpen={isImportOpen}
        onClose={() => setIsImportOpen(false)}
        onImport={() => refetch()}
      />
    </>
  )
}

ExerciseSelector.defaultProps = {
  buttonProps: {},
}

export default ExerciseSelector
