import { Callout, H6 } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { MilestoneState } from '@inject/graphql/fragments/MilestoneState.generated'
import type { Dispatch, FC } from 'react'
import type { selectedReducerActionProps } from '../Overview/selectedReducer'
import useFormatTimestamp from '../useFormatTimestamp'

export const milestoneCard = css`
  flex: 0;
  flex-grow: 0;
  white-space: nowrap;
  text-align: center;
  height: 69;
  cursor: pointer;

  &:hover {
    box-shadow: 0 2px 6px rgb(17 20 24 / 10%);
  }

  &:active {
    box-shadow: 0 2px 6px rgb(17 20 24 / 15%);
  }
`

interface MilestoneCardProps {
  milestoneState: MilestoneState
  selectedDispatch: Dispatch<selectedReducerActionProps>
}

const MilestoneCard: FC<MilestoneCardProps> = ({
  milestoneState,
  selectedDispatch,
}) => {
  const formatTimestamp = useFormatTimestamp()

  return (
    <Callout
      className={milestoneCard}
      intent={milestoneState.reached ? 'success' : undefined}
      icon={null}
      onClick={() =>
        selectedDispatch({ type: 'selectMilestones', milestoneState })
      }
    >
      <H6
        style={{
          marginBottom: 0,
          transform: milestoneState.reached ? undefined : 'translateY(50%)',
        }}
      >
        {milestoneState.milestone.name}
      </H6>
      {milestoneState.reached ? (
        <span style={{ fontSize: 12 }}>
          {formatTimestamp(milestoneState.timestampReached)}
        </span>
      ) : (
        ''
      )}
    </Callout>
  )
}

export default MilestoneCard
