import { Button, ControlGroup, Divider, HTMLSelect } from '@blueprintjs/core'
import type { FC } from 'react'
import { useState } from 'react'
import { saveSvgAsPng } from 'save-svg-as-png'

const getSnapshotFilename = () => {
  const now = new Date()
  return `inject-overview-${now.toLocaleDateString()}-${now.toLocaleTimeString()}`
}

const downloadSVG = (elementId: string) => {
  const svgElement = document.getElementById(elementId)
  if (!svgElement) throw new Error(`element with id ${elementId} not found`)
  const svgString = new XMLSerializer().serializeToString(svgElement)
  const dataURL = `data:image/svg+xml;base64,${btoa(svgString)}`
  const downloadLink = document.createElement('a')
  downloadLink.href = dataURL
  downloadLink.download = `${getSnapshotFilename()}.svg`
  downloadLink.click()
}

const downloadPNG = (elementId: string) => {
  const svgElement = document.getElementById(elementId)
  if (!svgElement) throw new Error(`element with id ${elementId} not found`)
  saveSvgAsPng(svgElement, `${getSnapshotFilename()}.png`)
}

interface DownloadSnapshotProps {
  elementId: string
}

const DownloadSnapshot: FC<DownloadSnapshotProps> = ({ elementId }) => {
  const [format, setFormat] = useState('.png')

  return (
    <ControlGroup>
      <Button
        minimal
        onClick={() => {
          format === '.png' ? downloadPNG(elementId) : downloadSVG(elementId)
        }}
      >
        Download snapshot
      </Button>
      <Divider />
      <HTMLSelect
        minimal
        options={['.png', '.svg']}
        onChange={event => setFormat(event.currentTarget.value)}
      />
    </ControlGroup>
  )
}

export default DownloadSnapshot
