import { Button } from '@blueprintjs/core'
import type { FC, ReactNode } from 'react'
import { useState } from 'react'
import { HIGHLIGHTED_COLOR, VIEW } from '../utilities'
import Label from './Label'

interface CardProps {
  tableView?: ReactNode | undefined
  plotView?: ReactNode | undefined
  label: string
}

const Card: FC<CardProps> = ({ tableView, plotView, label }) => {
  const [view, setView] = useState(tableView ? VIEW.TABLE : VIEW.PLOT)

  if (!tableView && !plotView) return <div />

  return (
    <div style={{ display: 'flex', flexDirection: 'column', height: '100%' }}>
      <div
        style={{
          display: 'flex',
          alignItems: 'flex-end',
          gap: '10px',
          marginBottom: '5px',
        }}
      >
        {tableView && plotView && (
          <Button
            style={{
              backgroundColor: HIGHLIGHTED_COLOR,
            }}
            minimal
            icon={view === VIEW.TABLE ? VIEW.PLOT : VIEW.TABLE}
            onClick={() =>
              setView(prev => (prev === VIEW.TABLE ? VIEW.PLOT : VIEW.TABLE))
            }
            title={
              view === VIEW.TABLE
                ? 'switch to plot view'
                : 'switch to table view'
            }
          />
        )}
        <Label text={label} />
      </div>

      <div style={{ overflow: 'auto', flex: 1 }}>
        {view === VIEW.TABLE ? tableView : plotView}
      </div>
    </div>
  )
}

Card.defaultProps = {
  tableView: undefined,
  plotView: undefined,
}

export default Card
