import TeamLabel from '@/components/TeamLabel'
import useTeamStateValidator from '@/instructor/InstructorTeamSelector/useTeamStateValidator'
import {
  Button,
  CardList,
  CheckboxCard,
  NonIdealState,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { toggleTeam, unsetTeams, useTeamStateMap } from '../vars/teams'

const InstructorTeams = () => {
  const teamStateMap = useTeamStateMap()
  const validator = useTeamStateValidator()

  return (
    <Section
      title={'Instructor Subscribed Teams'}
      subtitle={`Current amount of synchronized teams: ${
        Object.keys(teamStateMap).length
      }`}
      rightElement={
        <div
          style={{
            display: 'flex',
            margin: '0.5rem',
            flexDirection: 'column',
            gap: '0.25rem',
            alignItems: 'center',
          }}
        >
          <Button
            fill
            onClick={() => {
              validator()
            }}
          >
            Revalidate subscribed teams
          </Button>
          <Button
            fill
            onClick={() => {
              unsetTeams()
            }}
          >
            Unset subscribed teams
          </Button>
        </div>
      }
    >
      <SectionCard>
        {Object.keys(teamStateMap).length === 0 && (
          <div style={{ padding: '1rem' }}>
            <NonIdealState
              icon='low-voltage-pole'
              description='Currently there are no active teams to manage'
            />
          </div>
        )}
        {Object.keys(teamStateMap).length > 0 && (
          <CardList>
            {Object.entries(teamStateMap).map(([key, value]) => (
              <CheckboxCard
                key={key}
                alignIndicator='right'
                showAsSelectedWhenChecked={false}
                checked={value.show}
                onClick={e => {
                  e.preventDefault()
                  toggleTeam(key)
                }}
              >
                <TeamLabel
                  teamId={value.team.id}
                  teamName={value.team.name}
                  exerciseName={value.team.exercise.name}
                  teamRole={value.team.role}
                />
              </CheckboxCard>
            ))}
          </CardList>
        )}
      </SectionCard>
    </Section>
  )
}

export default InstructorTeams
