import { Button, InputGroup, Section } from '@blueprintjs/core'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import { useLocalStorageState } from 'ahooks'

const Notification = () => {
  const FormCleaner = () => {
    const { clearNotify } = useNotifyContext()
    return (
      <Button fill onClick={clearNotify}>
        Clear All Notifications
      </Button>
    )
  }
  const FormSetter = () => {
    const [count, setCount] = useLocalStorageState('notificationLimit', {
      defaultValue: 10,
      deserializer: v => Number(v),
      serializer: v => v.toString(),
    })
    return (
      <InputGroup
        fill
        type='number'
        value={(count as number).toString()}
        onChange={e => setCount(Number(e.target.value))}
      />
    )
  }

  return (
    <Section
      title='Notifications'
      subtitle='Change the number of notifications to display.'
      rightElement={
        <div
          style={{
            display: 'flex',
            margin: '0.5rem',
            flexDirection: 'column',
            gap: '0.25rem',
            alignItems: 'center',
          }}
        >
          <FormSetter />
          <FormCleaner />
        </div>
      }
    />
  )
}

export default Notification
