import { type ButtonProps } from '@blueprintjs/core'
import type { Exercise } from '@inject/graphql/fragments/Exercise.generated'
import CardList from '@inject/shared/components/CardList'
import { type FC } from 'react'
import ExerciseCard from './ExerciseCard'

type SelectingDetails = {
  onSelect: (exercise: Exercise) => void
}

type ManagingDetails = {
  startButtonProps: (exercise: Exercise) => ButtonProps
  removeButtonProps: (exercise: Exercise) => ButtonProps
  pauseButtonProps: (exercise: Exercise) => ButtonProps
}

export type BaseExerciseListProps = {
  isSelected?: (exercise: Exercise) => boolean
} & (
  | {
      type: 'selecting'
      details: SelectingDetails
    }
  | { type: 'managing'; details: ManagingDetails }
)

type ExerciseListProps = BaseExerciseListProps & {
  exercises: Exercise[]
}

const ExerciseListComponent: FC<ExerciseListProps> = ({
  exercises,
  isSelected,
  type,
  details,
}) => (
  <CardList>
    {exercises.map(exercise =>
      type === 'selecting' ? (
        <ExerciseCard
          key={exercise.id}
          exercise={exercise}
          isSelected={isSelected ? isSelected(exercise) : undefined}
          type='selecting'
          details={{ onSelect: () => details.onSelect(exercise) }}
        />
      ) : (
        <ExerciseCard
          key={exercise.id}
          exercise={exercise}
          isSelected={exercise.running}
          type='managing'
          details={{
            startButtonProps: details.startButtonProps(exercise),
            removeButtonProps: details.removeButtonProps(exercise),
            pauseButtonProps: details.pauseButtonProps(exercise),
          }}
        />
      )
    )}
  </CardList>
)

export default ExerciseListComponent
