import { useNavigate } from '@/router'
import {
  Button,
  Dialog,
  DialogBody,
  DialogFooter,
  Text,
} from '@blueprintjs/core'
import type { FC } from 'react'
import { useState } from 'react'

interface ExitButtonProps {
  hideLabel?: boolean
}

const ExitButton: FC<ExitButtonProps> = ({ hideLabel }) => {
  const nav = useNavigate()
  const [open, setOpen] = useState(false)

  return (
    <>
      <Button
        active={open}
        icon='cross-circle'
        intent='danger'
        alignText='left'
        fill
        minimal
        text={!hideLabel && 'Exit'}
        title='Exit'
        onClick={() => setOpen(true)}
      />
      <Dialog
        title='Exit'
        icon='log-out'
        onClose={() => setOpen(false)}
        isOpen={open}
      >
        <DialogBody>
          <Text>Are you sure you want to return to the main menu?</Text>
        </DialogBody>
        <DialogFooter
          actions={
            <>
              <Button intent='danger' onClick={() => nav('/')} text='Exit' />
              <Button
                intent='primary'
                onClick={() => setOpen(false)}
                text='Cancel'
              />
            </>
          }
        />
      </Dialog>
    </>
  )
}

export default ExitButton
