import { useHost } from '@inject/graphql/connection/host'
import type { FileInfo } from '@inject/graphql/fragments/FileInfo.generated'
import { downloadFileUrl } from '@inject/shared/config'
import { type FC } from 'react'
import FileViewRedirectButton from '.'
import FileButtonComponent from './FileButtonComponent'

interface FileButtonProps {
  teamId: string
  fileInfo: FileInfo
  exerciseId: string
  inInstructor?: boolean
  allowRedirect: boolean
}

const FileButton: FC<FileButtonProps> = ({
  fileInfo,
  teamId,
  exerciseId,
  inInstructor,
  allowRedirect,
}) => {
  const host = useHost()

  return allowRedirect ? (
    <FileViewRedirectButton
      exerciseId={exerciseId}
      fileInfo={fileInfo}
      teamId={teamId}
      inInstructor={inInstructor}
    />
  ) : (
    <FileButtonComponent
      href={downloadFileUrl(
        host || '',
        teamId,
        fileInfo.id,
        inInstructor ?? false
      )}
    >
      {fileInfo.fileName}
    </FileButtonComponent>
  )
}

export default FileButton
