import { useNavigate } from '@/router'
import { useHost } from '@inject/graphql/connection/host'
import type { FileInfo } from '@inject/graphql/fragments/FileInfo.generated'
import { downloadFileUrl } from '@inject/shared/config'
import { type FC } from 'react'
import { useLocation } from 'react-router-dom'
import FileButtonComponent from './FileButtonComponent'

interface DocumentViewButtonProps {
  teamId: string
  fileInfo: FileInfo
  exerciseId: string
  inInstructor?: boolean
}

/*
 * supported file extension list for current version 1.14.0
 * https://www.npmjs.com/package/@cyntler/react-doc-viewer/v/1.14.0
 */

const SUPPORTED_FILE_EXTENSIONS = [
  'bmp',
  'gif',
  'htm',
  'html',
  'jpg',
  'jpeg',
  'pdf',
  'png',
  'tiff',
  'txt',
]

const FileViewRedirectButton: FC<DocumentViewButtonProps> = ({
  fileInfo,
  teamId,
  exerciseId,
  inInstructor,
}) => {
  const navigate = useNavigate()
  const loc = useLocation().pathname
  const host = useHost()

  const parsedFilename = fileInfo.fileName.split('.')
  const isSupported = SUPPORTED_FILE_EXTENSIONS.includes(
    parsedFilename[parsedFilename.length - 1] || ''
  )

  const handleClick = () => {
    if (!isSupported) {
      return
    }

    if (loc.startsWith('/trainee')) {
      navigate('/trainee/:exerciseId/:teamId/file/:fileId', {
        params: { exerciseId, fileId: fileInfo.id, teamId },
      })
    }
    if (loc.startsWith('/instructor')) {
      navigate('/instructor/:exerciseId/:teamId/file/:fileId', {
        params: { exerciseId, fileId: fileInfo.id, teamId },
      })
    }
    if (loc.startsWith('/analyst')) {
      navigate('/analyst/:exerciseId/:teamId/file/:fileId', {
        params: { exerciseId, fileId: fileInfo.id, teamId },
      })
    }
  }

  return (
    <FileButtonComponent
      onClick={handleClick}
      href={
        isSupported
          ? undefined
          : downloadFileUrl(
              host || '',
              teamId,
              fileInfo.id,
              inInstructor ?? false
            )
      }
    >
      {fileInfo.fileName}
    </FileButtonComponent>
  )
}

export default FileViewRedirectButton
