import useEditorStorage from '@/editor/useEditorStorage'
import { InputGroup, Label, TextArea } from '@blueprintjs/core'
import { memo, useEffect, useState, type FC } from 'react'

interface ExerciseInformationFormProps {
  onInputChange: (name: string, description: string, trainee: string) => void
}

const ExerciseInformationPage: FC<ExerciseInformationFormProps> = ({
  onInputChange,
}) => {
  const [config, setConfig] = useEditorStorage()
  const [name, setName] = useState(config?.name || '')
  const [description, setDescription] = useState(config?.description || '')
  const [trainee, setTrainee] = useState(config?.trainee || '')

  useEffect(() => {
    setConfig({
      ...config,
      name,
      description,
      trainee,
    })
    onInputChange(name, description, trainee)
  }, [name, description, trainee])

  return (
    <div>
      <Label>
        Name
        <InputGroup
          placeholder='Input text'
          value={name}
          onChange={e => setName(e.target.value)}
        />
      </Label>
      <Label>
        Description
        <TextArea
          value={description}
          style={{
            width: '100%',
            height: '5rem',
            resize: 'none',
            overflowY: 'auto',
          }}
          placeholder='Input text'
          onChange={e => setDescription(e.target.value)}
        />
      </Label>
      <Label>
        Who is your trainee?
        <InputGroup
          placeholder='Input text'
          value={trainee}
          onChange={e => setTrainee(e.target.value)}
        />
      </Label>
    </div>
  )
}

export default memo(ExerciseInformationPage)
