import useEditorStorage from '@/editor/useEditorStorage'
import { CheckboxCard, Classes } from '@blueprintjs/core'
import { memo, useEffect, useState, type FC } from 'react'
import { INTRO_CONDITIONS } from '../utils'

interface IntroductionFormProps {
  onInputChange: (conditions: boolean[]) => void
}

const IntroductionForm: FC<IntroductionFormProps> = ({ onInputChange }) => {
  const [config, setConfig] = useEditorStorage()
  const [conditionChecked, setConditionChecked] = useState(
    config?.checked || INTRO_CONDITIONS.map(() => false)
  )

  useEffect(() => {
    setConfig({
      ...config,
      checked: conditionChecked,
    })
    onInputChange(conditionChecked)
  }, [conditionChecked])

  return (
    <div>
      {INTRO_CONDITIONS.map((condition, i) => (
        <CheckboxCard
          key={i}
          checked={conditionChecked[i]}
          showAsSelectedWhenChecked={false}
          onChange={() =>
            setConditionChecked(prev => [
              ...prev.slice(0, i),
              !prev[i],
              ...prev.slice(i + 1),
            ])
          }
        >
          {condition.name} -{' '}
          <span className={Classes.TEXT_MUTED}>{condition.description}</span>
        </CheckboxCard>
      ))}
    </div>
  )
}

export default memo(IntroductionForm)
