import type { OptionProps } from '@blueprintjs/core'
import { HTMLSelect, Label } from '@blueprintjs/core'
import { useLiveQuery } from 'dexie-react-hooks'
import { memo, useMemo, type FC } from 'react'
import EmailAddressForm from '../EmailAddressForm'
import { db } from '../indexeddb/db'
import type { EmailAddressInfo } from '../indexeddb/types'

interface EmailAddressFormProps {
  emailAddressId: number
  onChange: (id: number) => void
}

const EmailAddressSelector: FC<EmailAddressFormProps> = ({
  emailAddressId,
  onChange,
}) => {
  const emailAddresses = useLiveQuery(() => db.emailAddresses.toArray(), [], [])

  const emailAddressOptions: OptionProps[] = useMemo(() => {
    if (emailAddresses === undefined || emailAddresses.length === 0) {
      return [
        {
          label: 'No email addresses',
          value: 0,
          disabled: true,
        },
      ]
    }

    return emailAddresses?.map((emailAddress: EmailAddressInfo) => ({
      value: emailAddress.id,
      label: emailAddress.address,
    }))
  }, [emailAddresses])

  return (
    <div style={{ display: 'flex', width: '100%' }}>
      <Label style={{ flexGrow: '1' }}>
        Address
        <HTMLSelect
          options={emailAddressOptions}
          value={emailAddressId}
          onChange={event => onChange(Number(event.currentTarget.value))}
        />
      </Label>
      <EmailAddressForm
        buttonProps={{
          minimal: true,
          icon: 'plus',
          style: { marginRight: '1rem' },
        }}
        onAdd={addressId => onChange(addressId)}
      />
    </div>
  )
}

export default memo(EmailAddressSelector)
