import type { EmailSelection } from '@/analyst/utilities'
import { Divider } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { EmailThread } from '@inject/graphql/fragments/EmailThread.generated'
import type { FC } from 'react'
import { useMemo } from 'react'
import {
  OPEN_COMPOSE_EVENT_TYPE,
  OPEN_REPLY_EVENT_TYPE,
} from '../EmailFormOverlay'
import EmailCard from './EmailCard'
import ThreadHeaderCard from './ThreadHeaderCard'
import ThreadLogCards from './ThreadLogCards'

const emailThread = css`
  flex: 2;
  display: flex;
  flex-direction: column;
`

const emailCardList = css`
  display: flex;
  flex-direction: column;
  flex: 1;
  overflow-y: auto;
  gap: 1rem;
  padding: 10px 20px;
`

interface TeamEmailsProps {
  exerciseId: string
  teamId: string
  emailThreads: EmailThread[]
  allowTabs?: boolean
  selectedTab?: EmailSelection
  onSelectReceived?: () => void
  onSelectSent?: () => void
  selectedEmailThread: EmailThread | undefined
  onClick: (emailThread: EmailThread) => void
  inAnalyst?: boolean
  allowComposing: boolean
  composeButtonTitle?: string
  allowReplying: boolean
  replyButtonTitle?: string
  inInstructor?: boolean
  allowForwarding: boolean
  forwardButtonTitle?: string
}

const TeamEmails: FC<TeamEmailsProps> = ({
  exerciseId,
  teamId,
  emailThreads,
  allowTabs,
  selectedTab,
  onSelectReceived,
  onSelectSent,
  selectedEmailThread,
  onClick,
  inAnalyst,
  allowComposing,
  composeButtonTitle,
  allowReplying,
  replyButtonTitle,
  inInstructor,
  allowForwarding,
  forwardButtonTitle,
}) => {
  const emails = useMemo(
    () =>
      [
        ...(selectedEmailThread?.emails.map(email => ({
          ...email,
          subject: selectedEmailThread.subject,
        })) || []),
      ].reverse(),
    [selectedEmailThread]
  )

  return (
    <>
      <div
        style={{
          display: 'flex',
          height: '100%',
        }}
      >
        <ThreadLogCards
          emailThreads={emailThreads}
          teamId={teamId}
          allowTabs={allowTabs}
          selectedTab={selectedTab}
          onSelectReceived={onSelectReceived}
          onSelectSent={onSelectSent}
          selectedEmailThreadId={selectedEmailThread?.id}
          onClick={onClick}
          inAnalyst={inAnalyst!}
          allowComposing={allowComposing}
          composeButtonTitle={composeButtonTitle}
          onCompose={() =>
            window.dispatchEvent(new Event(OPEN_COMPOSE_EVENT_TYPE))
          }
        />

        {selectedEmailThread ? (
          <div className={emailThread}>
            <ThreadHeaderCard
              title={selectedEmailThread.subject}
              subtitle={selectedEmailThread.participants
                .map(participant => participant.address)
                .join(', ')}
              allowReplying={allowReplying}
              replyButtonTitle={replyButtonTitle}
              onReply={() =>
                window.dispatchEvent(
                  new CustomEvent(OPEN_REPLY_EVENT_TYPE, {
                    detail: { emailThread: selectedEmailThread },
                  })
                )
              }
            />
            <Divider />
            <div className={emailCardList}>
              {emails.map(email => (
                <EmailCard
                  key={email.id}
                  exerciseId={exerciseId}
                  teamId={teamId}
                  email={email}
                  inAnalyst={inAnalyst}
                  inInstructor={inInstructor}
                  allowForwarding={allowForwarding}
                  forwardButtonTitle={forwardButtonTitle}
                  subject={email.subject}
                />
              ))}
            </div>
          </div>
        ) : (
          <div />
        )}
      </div>
    </>
  )
}

TeamEmails.defaultProps = {
  inAnalyst: false,
  inInstructor: false,
}

export default TeamEmails
