import { useNavigate } from '@/router'
import { Button, ButtonGroup, Card } from '@blueprintjs/core'
import type { Definition } from '@inject/graphql/fragments/Definition.generated'
import { useDeleteDefinition } from '@inject/graphql/mutations/DeleteDefinition.generated'
import { GetDefinitionsDocument } from '@inject/graphql/queries/GetDefinitions.generated'
import { GetExercisesDocument } from '@inject/graphql/queries/GetExercises.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC } from 'react'
import { memo, useCallback } from 'react'

interface DefinitionProps {
  definition: Definition
}

const DefinitionComp: FC<DefinitionProps> = ({ definition }) => {
  const { id, name } = definition
  const nav = useNavigate()
  const [mutate] = useDeleteDefinition({
    variables: {
      definitionId: id,
    },
    refetchQueries: [GetDefinitionsDocument, GetExercisesDocument],
  })
  const { notify } = useNotifyContext()
  const handleRemove = useCallback(() => {
    mutate()
      .then(() => {
        notify(`Definition ${id} removed`)
      })
      .catch((error: Error) => {
        if (error.message === 'Cannot delete running exercise.') {
          notify('Cannot delete a definition with a running exercise', {
            intent: 'danger',
            icon: 'error',
          })
        } else {
          throw error
        }
      })
  }, [id, mutate, notify])

  return (
    <Card
      style={{
        display: 'flex',
        flexDirection: 'column',
        justifyContent: 'space-between',
      }}
    >
      <div>
        <h3>{name || id}</h3>
      </div>
      <ButtonGroup
        vertical
        alignText='left'
        style={{ marginTop: '1rem', alignSelf: 'end' }}
      >
        <Button type='button' onClick={handleRemove} icon='cross'>
          Remove
        </Button>
        <Button
          type='button'
          onClick={() =>
            nav('/users/definition/:definitionId', {
              params: { definitionId: id },
            })
          }
          icon='people'
          fill
        >
          Access
        </Button>
      </ButtonGroup>
    </Card>
  )
}
export default memo(DefinitionComp)
