import { Button, Dialog, DialogBody } from '@blueprintjs/core'
import type { FC } from 'react'
import { useState } from 'react'
import InjectForm from './InjectForm'

interface InstructorInjectProps {
  teamId: string | undefined
  exerciseId: string | undefined
  hideLabel?: boolean
}

const InstructorInject: FC<InstructorInjectProps> = ({
  teamId,
  exerciseId,
  hideLabel,
}) => {
  const [isComposerOpen, setIsComposerOpen] = useState(false)

  return (
    <>
      <Button
        active={isComposerOpen}
        fill
        minimal
        alignText='left'
        disabled={!teamId || !exerciseId}
        title='Send an inject'
        icon='annotation'
        text={!hideLabel && 'Send an inject'}
        onClick={() => setIsComposerOpen(!isComposerOpen)}
      />
      {teamId && exerciseId && (
        <Dialog
          canOutsideClickClose={false}
          isOpen={isComposerOpen}
          onClose={() => {
            setIsComposerOpen(false)
          }}
          title='Send an inject into the INFO channel of the selected team'
          icon='annotation'
        >
          <DialogBody>
            <InjectForm
              teamId={teamId}
              exerciseId={exerciseId}
              setIsOpen={setIsComposerOpen}
            />
          </DialogBody>
        </Dialog>
      )}
    </>
  )
}

export default InstructorInject
