import { Callout, H5 } from '@blueprintjs/core'
import notEmpty from '@inject/shared/utils/notEmpty'

import type { InjectOption } from '@inject/graphql/fragments/InjectOption.generated'
import type { InjectSelection } from '@inject/graphql/fragments/InjectSelections.generated'
import { useSelectTeamInjectOption } from '@inject/graphql/mutations/SelectTeamInjectOption.generated'
import { useWriteInjectSelectionConfirmation } from '@inject/graphql/mutations/clientonly/WriteInjectSelectionConfirmation.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import type { FC } from 'react'
import { useCallback } from 'react'
import InjectCardOption from './InjectCardOption'

interface InjectOptionGroupProps {
  selection: InjectSelection
  onSentSuccessfully: () => void
  teamId: string
  exerciseId: string
}

const InjectOptionGroup: FC<InjectOptionGroupProps> = ({
  selection,
  onSentSuccessfully,
  teamId,
  exerciseId,
}) => {
  const { id, name, options } = selection

  const { notify } = useNotifyContext()
  const [mutate, { loading }] = useSelectTeamInjectOption()
  const [update] = useWriteInjectSelectionConfirmation()

  const onSend = useCallback(
    (option: InjectOption) => {
      mutate({
        variables: {
          selectTeamInjectInput: {
            teamId,
            selectionId: selection.id,
            optionEmail: false,
            content: option.content.raw,
            activateMilestone: option.control.activateMilestone,
            deactivateMilestone: option.control.deactivateMilestone,
            fileId: option.content.fileInfo?.id,
            sender: option.sender,
          },
        },
      })
        .then(() => {
          update({
            variables: {
              injectSelectionId: selection.id,
            },
          })
          onSentSuccessfully()
        })
        .catch(err => {
          notify(`Error: ${err.message}`, { intent: 'danger' })
        })
    },
    [mutate, notify, onSentSuccessfully, selection.id, teamId, update]
  )

  return (
    <Callout
      style={{
        margin: '1em',
      }}
      key={name}
    >
      <H5>{name}</H5>
      {options.filter(notEmpty).map(option => (
        <InjectCardOption
          onSend={() => onSend(option)}
          key={option.id}
          selectionId={id}
          option={option}
          loading={loading}
          teamId={teamId}
          exerciseId={exerciseId}
        />
      ))}
    </Callout>
  )
}

export default InjectOptionGroup
