import { useNavigate } from '@/router'
import { Button } from '@blueprintjs/core'
import { useCallback, type FC } from 'react'
import { matchPath } from 'react-router-dom'

interface LearningObjectivesButtonProps {
  exerciseId: string | undefined
  teamId: string | undefined
  hideLabel: boolean
  pathname: string
}

const LearningObjectivesButton: FC<LearningObjectivesButtonProps> = ({
  exerciseId,
  teamId,
  hideLabel,
  pathname,
}) => {
  const nav = useNavigate()

  const handleClick = useCallback(() => {
    if (teamId && exerciseId) {
      nav('/instructor/:exerciseId/:teamId/learning-objectives', {
        params: { exerciseId, teamId },
      })
    }
  }, [exerciseId, nav, teamId])

  return (
    <Button
      icon='learning'
      active={
        matchPath(
          {
            path: '/instructor/:exerciseId/:teamId/learning-objectives',
            end: false,
          },
          pathname
        ) !== null
      }
      alignText='left'
      fill
      disabled={!teamId || !exerciseId}
      minimal
      text={!hideLabel && 'Learning objectives'}
      title='Learning objectives'
      onClick={handleClick}
      style={{ whiteSpace: 'nowrap' }}
    />
  )
}

export default LearningObjectivesButton
