import type { ButtonProps } from '@blueprintjs/core'
import { Button } from '@blueprintjs/core'
import useApolloClient from '@inject/graphql/client/useApolloClient'
import { GetRunningExercisesDocument } from '@inject/graphql/queries/GetRunningExercises.generated'
import { useCountDown } from 'ahooks'
import { useState } from 'react'

const Reloader = (
  props: Omit<ButtonProps, 'rightIcon' | 'title' | 'onClick' | 'children'>
) => {
  const client = useApolloClient()
  const fn = () => {
    setTargetDate(Date.now() + 10500)
    client.refetchQueries({ include: [GetRunningExercisesDocument] })
  }
  const [targetDate, setTargetDate] = useState(Date.now() + 10500)
  const [, { seconds }] = useCountDown({
    targetDate,
    onEnd: () => {
      fn()
    },
  })
  return (
    <Button
      rightIcon='refresh'
      title='Reload the team list'
      onClick={() => {
        fn()
      }}
      {...props}
    >
      <span
        style={{
          minWidth: '3ch',
          display: 'inline-block',
          textAlign: 'center',
        }}
      >
        {`${seconds}s`}
      </span>
    </Button>
  )
}

export default Reloader
