import ErrorMessage from '@/components/ErrorMessage'
import TeamLabel from '@/components/TeamLabel'
import { useNavigate } from '@/router'
import {
  Card,
  CardList,
  Classes,
  NonIdealState,
  Section,
  SectionCard,
} from '@blueprintjs/core'
import { ChevronRight } from '@blueprintjs/icons'
import { css } from '@emotion/css'
import type { Team } from '@inject/graphql/fragments/Team.generated'
import { useGetRunningExercises } from '@inject/graphql/queries/GetRunningExercises.generated'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useMemo } from 'react'
import Reloader from '../Reloader'

const between = css`
  justify-content: space-between;
  gap: 1rem;
`

const TeamSelector = () => {
  const { error, data } = useGetRunningExercises({
    fetchPolicy: 'network-only',
  })
  const nav = useNavigate()

  const exercises = useMemo(
    () => (data?.exercises || []).filter(notEmpty),
    [data]
  )

  if (error) {
    return (
      <ErrorMessage>
        <h1>Error!</h1>
        <p>{error.message}</p>
      </ErrorMessage>
    )
  }

  return (
    <Section
      title='Trainee Team Selection'
      rightElement={<Reloader minimal fill />}
    >
      {exercises.length === 0 && (
        <div style={{ padding: '1rem' }}>
          <NonIdealState
            icon='low-voltage-pole'
            description='There are no exercises active'
          />
        </div>
      )}
      {exercises.map(exercise => (
        <SectionCard padded key={exercise.id}>
          <h3
            style={{ paddingBottom: '1rem' }}
          >{`Exercise: ${exercise.name}`}</h3>
          <CardList bordered>
            {exercise.teams.map((team: Team) => (
              <Card
                interactive
                onClick={() =>
                  nav('/trainee/:exerciseId/:teamId', {
                    params: {
                      exerciseId: exercise.id,
                      teamId: team.id,
                    },
                  })
                }
                className={between}
                key={team.id}
              >
                <TeamLabel
                  teamId={team.id}
                  teamName={team.name}
                  teamRole={team.role}
                />
                <ChevronRight className={Classes.TEXT_MUTED} />
              </Card>
            ))}
          </CardList>
        </SectionCard>
      ))}
    </Section>
  )
}

export default TeamSelector
