import { Button, HTMLSelect } from '@blueprintjs/core'
import type { User } from '@inject/graphql/fragments/User.generated'
import { useChangeUserData } from '@inject/graphql/mutations/ChangeUserData.generated'
import { useGetGroups } from '@inject/graphql/queries/GetGroups.generated'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import notEmpty from '@inject/shared/utils/notEmpty'
import type { FC } from 'react'
import { useCallback, useEffect, useMemo, useState } from 'react'
import { detailRow, detailRowName } from '.'
import { accountStatusesOptions } from '../utilities'

interface UserDetailSettingProps {
  user: User
}

const UserDetailSetting: FC<UserDetailSettingProps> = ({ user }) => {
  const [changeUserData, { loading }] = useChangeUserData()
  const { data: groupsData } = useGetGroups({
    fetchPolicy: 'cache-first',
  })
  const { notify } = useNotifyContext()

  const userGroups = useMemo(
    () => groupsData?.groups?.filter(notEmpty).map(group => group.name) || [],
    [groupsData]
  )

  const [userGroup, setUserGroup] = useState(user?.group || '')

  const [accountStatus, setAccountStatus] = useState(
    (user?.isActive || false).toString()
  )

  useEffect(() => {
    setUserGroup(user?.group || '')
    setAccountStatus((user?.isActive || false).toString())
  }, [user])

  const handleButton = useCallback(() => {
    changeUserData({
      variables: {
        userId: user.id,
        group: userGroup,
        active: accountStatus == 'true',
      },
      onCompleted: () => {
        notify('User data changed')
      },
      onError: error => {
        notify(error.message, { intent: 'danger' })
      },
    })
  }, [userGroup, accountStatus, notify])

  return (
    <>
      <div className={detailRow} style={{ display: 'flex' }}>
        <span className={detailRowName}>Group: </span>{' '}
        <HTMLSelect
          fill
          options={userGroups}
          value={userGroup}
          onChange={e => setUserGroup(e.target.value)}
        />
      </div>
      <div className={detailRow} style={{ display: 'flex' }}>
        <span className={detailRowName}>Active: </span>{' '}
        <HTMLSelect
          fill
          options={accountStatusesOptions}
          value={accountStatus}
          onChange={e => setAccountStatus(e.target.value)}
        />
      </div>
      <Button
        type='button'
        intent='primary'
        onClick={handleButton}
        loading={loading}
      >
        Save changes
      </Button>
    </>
  )
}

export default UserDetailSetting
