import UserTable from '@/users/UserTable'
import { Button } from '@blueprintjs/core'
import type { FC } from 'react'
import { useState } from 'react'

interface UserTableSelectionProps {
  onBack: () => void
  onAssign: (ids: string[]) => void
  assignTitle: string
}

const UserTableSelection: FC<UserTableSelectionProps> = ({
  onBack,
  onAssign,
  assignTitle,
}) => {
  const [selectedUsers, setSelectedUsers] = useState<string[]>([])

  return (
    <>
      <UserTable
        allowAddingUsers={false}
        onClick={(id: string) =>
          selectedUsers.includes(id)
            ? setSelectedUsers(prev => {
                const i = selectedUsers.indexOf(id)
                return [...prev.slice(0, i), ...prev.slice(i + 1)]
              })
            : setSelectedUsers(prev => [...prev, id])
        }
        selectedUsers={selectedUsers}
      />
      <div
        style={{
          display: 'flex',
          justifyContent: 'space-between',
          marginTop: '1rem',
        }}
      >
        <Button onClick={() => onBack()} text='Back to list' />
        <Button
          intent='primary'
          onClick={() => {
            onAssign(selectedUsers)
            setSelectedUsers([])
          }}
          text={assignTitle}
        />
      </div>
    </>
  )
}

export default UserTableSelection
