import { Button, ButtonGroup, Checkbox, NonIdealState } from '@blueprintjs/core'
import type { RestrictedUser } from '@inject/graphql/fragments/RestrictedUser.generated'
import type { FC } from 'react'
import { useState } from 'react'

interface UserSelectionProps {
  users: RestrictedUser[]
  onRemove: (ids: string[]) => void
  onAssign: () => void
  assignTitle: string
  removeTitle: string
}

const UsersSelection: FC<UserSelectionProps> = ({
  users,
  onRemove,
  onAssign,
  assignTitle,
  removeTitle,
}) => {
  const [selectedUsers, setSelectedUsers] = useState(
    new Array(users.length).fill(false)
  )

  return (
    <>
      <div style={{ marginBottom: '1rem' }}>
        {users.length === 0 && (
          <NonIdealState
            layout='horizontal'
            icon='blocked-person'
            description='There are no users assigned'
          />
        )}
        {users.map((user, i) => (
          <Checkbox
            key={user.id}
            label={user.username}
            checked={selectedUsers[i]}
            onChange={() =>
              setSelectedUsers(prev => [
                ...prev.slice(0, i),
                !prev[i],
                ...prev.slice(i + 1),
              ])
            }
          />
        ))}
      </div>
      <ButtonGroup style={{ display: 'flex', justifyContent: 'space-between' }}>
        <Button
          onClick={() => {
            onRemove(
              users.filter((_user, i) => selectedUsers[i]).map(user => user.id)
            )
            setSelectedUsers(new Array(users.length).fill(false))
          }}
          icon='trash'
          text={removeTitle}
          disabled={selectedUsers.every(val => !val)}
        />
        <Button
          intent='primary'
          onClick={onAssign}
          icon='plus'
          text={assignTitle}
        />
      </ButtonGroup>
    </>
  )
}

export default UsersSelection
