import { Button, Dialog, FileInput } from '@blueprintjs/core'
import useApolloClient from '@inject/graphql/client/useApolloClient'
import { useHost } from '@inject/graphql/connection/host'
import Box from '@inject/shared/components/Box'
import { uploadUsersUrl } from '@inject/shared/config'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import csrfFetch from '@inject/shared/utils/csrfFetch'
import type { ChangeEvent } from 'react'
import { useState } from 'react'

const UsersUploader = () => {
  const [open, setOpen] = useState<boolean>(false)
  const [file, setFile] = useState<File | undefined>()
  const { notify } = useNotifyContext()
  const host = useHost()
  const client = useApolloClient()

  const text = file ? file.name : 'Choose users csv'

  const handleFileChange = (e: ChangeEvent<HTMLInputElement>) => {
    if (e.target.files) {
      setFile(e.target.files[0])
    }
  }

  const handleUploadEvent = () => {
    if (!file) {
      return
    }

    const data = new FormData()
    data.append('file', file)

    csrfFetch(uploadUsersUrl(host || ''), {
      method: 'POST',
      body: data,
      credentials: 'include',
    })
      .then(res => res.json())
      .then((res: { status: string; detail: string }) => {
        notify(`${res.status} - ${res.detail}`)
        setOpen(false)
        client.refetchQueries({ include: ['GetUsers'] })
      })
      .catch((err: { status: string; detail: string }) =>
        notify(`${err.status} - ${err.detail}`, {
          intent: 'danger',
        })
      )
  }
  return (
    <>
      <Button
        type='button'
        intent='primary'
        onClick={() => {
          setOpen(true)
        }}
      >
        Add new users
      </Button>
      <Dialog
        title='Add users'
        isOpen={open}
        onClose={() => setOpen(false)}
        icon='add'
      >
        <Box>
          <FileInput text={text} onInputChange={handleFileChange} />
        </Box>
        <Button type='button' onClick={handleUploadEvent}>
          Upload
        </Button>
      </Dialog>
    </>
  )
}

export default UsersUploader
