import ToolAction from '@/actionlog/ToolAction'
import type { Section } from '@/components/Sidebar'
import Sidebar from '@/components/Sidebar'
import type { ExtendedTool } from '@inject/graphql/fragments/ExtendedToolType.generated'
import { useGetExtendedTeamTools } from '@inject/graphql/queries/GetExtendedTeamTools.generated'
import notEmpty from '@inject/shared/utils/notEmpty'
import type { FC } from 'react'
import { memo, useMemo } from 'react'

const UNDEFINED_ID = 'undefined'

interface ToolbarProps {
  teamId: string
}

const Toolbar: FC<ToolbarProps> = ({ teamId }) => {
  const { data } = useGetExtendedTeamTools({
    variables: {
      teamId,
    },
  })
  const process = (data?.extendedTeamTools ?? []).filter(notEmpty)

  const groups: Map<string | undefined, ExtendedTool[]> = useMemo(() => {
    const uncategorized: ExtendedTool[] = []

    const groupsMap = new Map<string | undefined, ExtendedTool[]>()
    process.forEach(tool => {
      const prefix = tool.name.split('_').at(0)

      if (!prefix || prefix === tool.name) {
        uncategorized.push(tool)
        return
      }

      if (groupsMap.has(prefix)) {
        groupsMap.get(prefix)?.push(tool)
      } else {
        groupsMap.set(prefix, [tool])
      }
    })

    groupsMap.set(groupsMap.size === 0 ? undefined : 'Other', uncategorized)

    return groupsMap
  }, [process])

  const sections: Section[] = [...groups.entries()].map(([key, value]) => ({
    name: key,
    node: (
      <>
        {value.map(tool => (
          <ToolAction
            key={tool.id || UNDEFINED_ID}
            grapheneTool={tool}
            teamId={teamId}
          />
        ))}
      </>
    ),
  }))

  return (
    <Sidebar
      position='right'
      sections={sections}
      width={300}
      title='Available tools'
    />
  )
}

export default memo(Toolbar)
