import type { FC, ReactNode } from 'react'
import { useMemo } from 'react'
import { createPortal } from 'react-dom'
import { useSubscriptionContext } from '../../context/SubscriptionContext'
import type { ActionLog } from '../../fragments/ActionLog.generated'
import EmailService from './actionLogComponents/EmailService'
import SubscriptionService from './actionLogComponents/SubscriptionService'
import TeamInjectService from './actionLogComponents/TeamInjectService'
import TeamMilestonesService from './actionLogComponents/TeamMilestonesService'

interface ManagerProps {
  getPopup?: (actionLog: ActionLog) => ReactNode
}

const Manager: FC<ManagerProps> = ({ getPopup }) => {
  const { teamIds, instructorContext } = useSubscriptionContext()
  const subscribed = useMemo(
    () =>
      teamIds.map(id => (
        <div key={id}>
          <SubscriptionService teamId={id} getPopup={getPopup} />
          <EmailService teamId={id} />
          {instructorContext && <TeamInjectService teamId={id} />}
          {instructorContext && <TeamMilestonesService teamId={id} />}
        </div>
      )),
    [teamIds, getPopup, instructorContext]
  )

  return (
    <>
      {/*
       * THIS IS A hack
       * whether you like it or not,
       * this code ensures that the subscription service is working
       * without it, the subscription service will not work
       */}
      {createPortal(
        <div
          style={{
            width: 0,
            height: 0,
            overflow: 'hidden',
            display: 'none',
          }}
          id='subscribedTeams'
        >
          {subscribed}
        </div>,
        document.getElementById('connection')!
      )}
      {/*
       * END OF THE hack
       * DO NOT REMOVE
       */}
    </>
  )
}

export default Manager
