import useInInstructor from '@inject/shared/hooks/useInInstructor'
import { useNotifyContext } from '@inject/shared/notification/contexts/NotifyContext'
import { usePopupContext } from '@inject/shared/popup/PopupContext'
import type { ReactNode } from 'react'
import { useEffect } from 'react'
import type { ActionLog } from '../fragments/ActionLog.generated'
import type { EmailDetails } from '../fragments/EmailDetails.generated'
import type { InjectDetails } from '../fragments/InjectDetails.generated'
import type { QuestionnaireDetails } from '../fragments/QuestionnaireDetails.generated'
import { useResetReadReceiptChannel } from '../mutations/clientonly/ResetReadReceiptChannel.generated'
import { useGetTeamActionLogs } from '../queries/GetTeamActionLogs.generated'
import type { TeamAction } from '../subscriptions/TeamActionLogs.generated'
import { TeamActionDocument } from '../subscriptions/TeamActionLogs.generated'

const useActionLogSubscription = ({
  teamId,
  getPopup,
}: {
  teamId: string
  getPopup?: (actionLog: ActionLog) => ReactNode
}) => {
  const [mutateReadChannel] = useResetReadReceiptChannel()
  const isInstructor = useInInstructor()

  // TODO: show 'active' overlays from query
  const query = useGetTeamActionLogs({
    variables: {
      teamId,
    },
    initialFetchPolicy: 'network-only',
    nextFetchPolicy: 'cache-first',
  })
  const { notify } = useNotifyContext()
  const { showPopup } = usePopupContext()
  const { subscribeToMore, networkStatus } = query
  useEffect(
    () =>
      subscribeToMore({
        document: TeamActionDocument,
        variables: {
          teamId,
        },
        updateQuery: (prev, { subscriptionData }) => {
          // Note: this is a hack, because Codegen implicitly typecasts subscriptionData to the parent query type, this is not desired
          const retypedData = subscriptionData.data as unknown as TeamAction
          if (!retypedData) return prev
          const newActionLog = retypedData.actionLogs?.actionLog
          const oldActionLog = prev.actionLogs || []

          if (!newActionLog) {
            return prev
          }

          // TODO: log the information whether the overlay was closed
          if (!isInstructor) {
            if (!getPopup) {
              throw new Error('getPopup is required for trainee view')
            }

            let details
            switch (newActionLog.type) {
              case 'INJECT':
                details = newActionLog.details as InjectDetails
                if (!details.overlay) {
                  break
                }

                showPopup(details.overlay.duration, getPopup(newActionLog))
                break
              case 'EMAIL':
                details = newActionLog.details as EmailDetails
                if (!details.overlay) {
                  break
                }

                showPopup(details.overlay.duration, getPopup(newActionLog))
                break
              case 'FORM':
                details = newActionLog.details as QuestionnaireDetails
                if (!details.overlay) {
                  break
                }

                showPopup(details.overlay.duration, getPopup(newActionLog))
                break
              default:
                break
            }
          }

          mutateReadChannel({
            variables: {
              channelId: newActionLog.channel.id,
              teamId: newActionLog.team.id,
            },
          })

          // TODO: don't notify if the EMAIL, CUSTOM_INJECT, or TOOL actionLog was created by the user
          const newMessageText = `New message in ${newActionLog.channel.name}`
          notify(
            isInstructor ? `Team ${teamId}: ${newMessageText}` : newMessageText,
            {},
            new Date(newActionLog.timestamp || 0)
          )

          return {
            ...prev,
            actionLogs: [...oldActionLog, newActionLog],
          }
        },
      }),
    [
      teamId,
      subscribeToMore,
      notify,
      isInstructor,
      mutateReadChannel,
      showPopup,
      getPopup,
    ]
  )

  return {
    networkStatus,
    teamId,
  }
}

export default useActionLogSubscription
