import milestoneStatesEqual from '@inject/graphql/utils/milestoneStatesEqual'
import notEmpty from '@inject/shared/utils/notEmpty'
import { useEffect } from 'react'
import { useGetAnalyticsMilestonesSuspenseQuery } from '../queries/GetAnalyticsMilestones.generated'
import type { ExerciseMilestones } from '../subscriptions/AnalyticsMilestones.generated'
import { ExerciseMilestonesDocument } from '../subscriptions/AnalyticsMilestones.generated'

const useAnalyticsMilestonesSubscription = (exerciseId: string) => {
  const query = useGetAnalyticsMilestonesSuspenseQuery({
    variables: { exerciseId },
  })

  const { subscribeToMore } = query
  useEffect(
    () =>
      subscribeToMore({
        document: ExerciseMilestonesDocument,
        variables: { exerciseId },
        updateQuery: (prev, { subscriptionData }) => {
          // Codegen implicitly typecasts subscriptionData to the parent query type, this is not desired
          const retypedData =
            subscriptionData.data as unknown as ExerciseMilestones
          if (
            !retypedData ||
            !retypedData.analyticsMilestonesSubscription ||
            !retypedData.analyticsMilestonesSubscription.milestones
          )
            return prev
          if (!prev.analyticsMilestones) return prev

          let newMilestones = prev.analyticsMilestones

          retypedData.analyticsMilestonesSubscription.milestones
            .filter(notEmpty)
            .forEach(newMilestoneState => {
              newMilestones = newMilestones
                .filter(notEmpty)
                .map(oldMilestoneState =>
                  oldMilestoneState.milestone.id ===
                    newMilestoneState.milestone.id &&
                  milestoneStatesEqual(oldMilestoneState, newMilestoneState)
                    ? newMilestoneState
                    : oldMilestoneState
                )
            })

          return {
            ...prev,
            analyticsMilestones: newMilestones,
          }
        },
      }),
    [exerciseId, subscribeToMore]
  )

  return query
}

export default useAnalyticsMilestonesSubscription
