import type { NotifyFunction } from '@inject/shared/notification/typing'
import { useApolloNetworkStatus } from '../client'

interface ApolloHealthStatusContextProps {
  notify: NotifyFunction
}

const useApolloHealthStatus = ({ notify }: ApolloHealthStatusContextProps) => {
  const status = useApolloNetworkStatus()

  if (status.queryError?.networkError) {
    notify(`Apollo Network error: ${status.queryError.networkError.message}`, {
      intent: 'danger',
    })
  }
  if (status.queryError?.graphQLErrors) {
    status.queryError.graphQLErrors.forEach(x => {
      // ignore auth errors
      if (x.message === 'Authentication failed') return
      notify(`Apollo Query error: ${x.message}`, {
        intent: 'danger',
      })
    })
  }
}

export default useApolloHealthStatus
