import type { Intent } from '@blueprintjs/core'
import { Button, NonIdealState } from '@blueprintjs/core'
import { css } from '@emotion/css'
import type { Placement } from '@floating-ui/react'
import type { FC } from 'react'
import { useContext, useEffect, useState } from 'react'
import usePopoverElement from '../popover/usePopoverElement'
import Notifications from './components/Notifications'
import NotificationListContext from './contexts/NotificationListContext'
import { useNotifyContext } from './contexts/NotifyContext'

interface NotificationDropdownProps {
  hideLabel?: boolean
  placement?: Placement
  fill?: boolean
}

const notificationBox = css`
  height: 300px;
  width: auto;
  display: grid;
  grid-template-columns: 1fr;
  grid-template-rows: auto max-content;
  gap: 0.25rem;
`

const NotificationDropdown: FC<NotificationDropdownProps> = ({
  hideLabel,
  placement,
  fill,
}) => {
  const value = useContext(NotificationListContext)
  const [open, setOpen] = useState<boolean>(false)
  const { clearNotify } = useNotifyContext()
  const { children, getReferenceProps, setReference } = usePopoverElement({
    open,
    setOpen,
    placement,
    children: (
      <div className={notificationBox}>
        <div style={{ overflowY: 'auto' }}>
          {value && value.length > 0 ? (
            value.map(x => <Notifications key={x.timestamp} {...x} />)
          ) : (
            <NonIdealState
              icon='low-voltage-pole'
              title='No notifications'
              description='There are no notifications to display'
            />
          )}
        </div>
        <div>
          <Button
            fill
            intent='danger'
            icon='trash'
            onClick={() => clearNotify()}
          >
            Clear All
          </Button>
        </div>
      </div>
    ),
  })

  const count = value?.length ?? 0
  const intent: Intent = count > 0 ? 'warning' : 'none'
  useEffect(() => {
    if (count === 0) {
      setOpen(false)
    }
  }, [count])

  return (
    <>
      <Button
        ref={setReference}
        intent={intent}
        active={open}
        icon='notifications'
        alignText='left'
        fill={fill}
        minimal
        text={!hideLabel && 'Notifications'}
        title='Notifications'
        onClick={() => setOpen(prev => !prev)}
        {...getReferenceProps}
      />
      {children}
    </>
  )
}

NotificationDropdown.defaultProps = {
  placement: 'bottom',
}

export default NotificationDropdown
